import java.util.*;

class Main{

    public static void main(String args[]){

	final int MAX = 30001;

	long[][] arr = new long[5][MAX];
	int[] inc = {1,5,10,25,50};

	for (int i = 0; i < MAX; i++)
	    arr[0][i] = 1;

	for (int i = 1; i < 5; i++)
	    for (int j = 0; j < MAX; j++){
		arr[i][j] += arr[i-1][j];
		if (j + inc[i] < MAX) 
		    arr[i][j+inc[i]] += arr[i][j];
	    }

	Scanner in = new Scanner(System.in);
	while(in.hasNextInt()){
	    int n = in.nextInt();
	    if (arr[4][n] == 1)
		System.out.println("There is only 1 way to produce " 
				   + n + " cents change.");
	    else
		System.out.println("There are " + arr[4][n] 
				   + " ways to produce " + n 
				   + " cents change.");
	}
    }


}
