import java.util.Scanner;

public class Main {
	static long[][] data;
	static int[] vals = {0, 1, 2, 5, 10};
	
	static {
		data = new long[5][6001];
		for (int i = 0; i < 5; i++)
			for (int j = 0; j < 6001; j++)
				data[i][j] = 1;
		calc();
	}
	
	static void calc() {
		for (int i = 1; i < 5; i++) {
			for (int j = 0; j < vals[i]; j++)
				data[i][j] = data[i - 1][j];
			for (int j = vals[i]; j < 6001; j++)
				data[i][j] = data[i - 1][j] + data[i][j - vals[i]];
		}		
	}
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		
		while(in.hasNext()) {
			int v = in.nextInt();
			long num = data[4][v / 5];
			if (num == 1) System.out.print("There is only 1 way to produce ");
			else System.out.print("There are " + num + " ways to produce ");
			System.out.println("" + v + " cents change.");
		}		
	}
}
